# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NotificationDestinationArgs', 'NotificationDestination']

@pulumi.input_type
class NotificationDestinationArgs:
    def __init__(__self__, *,
                 properties: pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]],
                 type: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_basic: Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']] = None,
                 auth_custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]] = None,
                 auth_token: Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secure_url: Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']] = None):
        """
        The set of arguments for constructing a NotificationDestination resource.

        :param pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]] properties: A nested block that describes a notification destination property. See Nested property blocks below for details.
        :param pulumi.Input[_builtins.str] type: The type of destination.  One of: `EMAIL`, `SERVICE_NOW`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `PAGERDUTY_ACCOUNT_INTEGRATION` or `PAGERDUTY_SERVICE_INTEGRATION`, `MICROSOFT_TEAMS`, `WORKFLOW_AUTOMATION`. The types `SLACK` and `SLACK_COLLABORATION` can only be imported, updated and destroyed (cannot be created via terraform).
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.bool] active: Indicates whether the destination is active.
        :param pulumi.Input['NotificationDestinationAuthBasicArgs'] auth_basic: A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        :param pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]] auth_custom_headers: A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        :param pulumi.Input['NotificationDestinationAuthTokenArgs'] auth_token: A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        :param pulumi.Input[_builtins.str] name: The name of the destination.
        :param pulumi.Input['NotificationDestinationSecureUrlArgs'] secure_url: A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        """
        pulumi.set(__self__, "properties", properties)
        pulumi.set(__self__, "type", type)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if active is not None:
            pulumi.set(__self__, "active", active)
        if auth_basic is not None:
            pulumi.set(__self__, "auth_basic", auth_basic)
        if auth_custom_headers is not None:
            pulumi.set(__self__, "auth_custom_headers", auth_custom_headers)
        if auth_token is not None:
            pulumi.set(__self__, "auth_token", auth_token)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secure_url is not None:
            pulumi.set(__self__, "secure_url", secure_url)

    @_builtins.property
    @pulumi.getter
    def properties(self) -> pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]]:
        """
        A nested block that describes a notification destination property. See Nested property blocks below for details.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]]):
        pulumi.set(self, "properties", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of destination.  One of: `EMAIL`, `SERVICE_NOW`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `PAGERDUTY_ACCOUNT_INTEGRATION` or `PAGERDUTY_SERVICE_INTEGRATION`, `MICROSOFT_TEAMS`, `WORKFLOW_AUTOMATION`. The types `SLACK` and `SLACK_COLLABORATION` can only be imported, updated and destroyed (cannot be created via terraform).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the destination is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter(name="authBasic")
    def auth_basic(self) -> Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']]:
        """
        A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        """
        return pulumi.get(self, "auth_basic")

    @auth_basic.setter
    def auth_basic(self, value: Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']]):
        pulumi.set(self, "auth_basic", value)

    @_builtins.property
    @pulumi.getter(name="authCustomHeaders")
    def auth_custom_headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]]:
        """
        A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        """
        return pulumi.get(self, "auth_custom_headers")

    @auth_custom_headers.setter
    def auth_custom_headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]]):
        pulumi.set(self, "auth_custom_headers", value)

    @_builtins.property
    @pulumi.getter(name="authToken")
    def auth_token(self) -> Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']]:
        """
        A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        """
        return pulumi.get(self, "auth_token")

    @auth_token.setter
    def auth_token(self, value: Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']]):
        pulumi.set(self, "auth_token", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the destination.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="secureUrl")
    def secure_url(self) -> Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']]:
        """
        A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        """
        return pulumi.get(self, "secure_url")

    @secure_url.setter
    def secure_url(self, value: Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']]):
        pulumi.set(self, "secure_url", value)


@pulumi.input_type
class _NotificationDestinationState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_basic: Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']] = None,
                 auth_custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]] = None,
                 auth_token: Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']] = None,
                 guid: Optional[pulumi.Input[_builtins.str]] = None,
                 last_sent: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 properties: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]]] = None,
                 secure_url: Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering NotificationDestination resources.

        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.bool] active: Indicates whether the destination is active.
        :param pulumi.Input['NotificationDestinationAuthBasicArgs'] auth_basic: A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        :param pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]] auth_custom_headers: A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        :param pulumi.Input['NotificationDestinationAuthTokenArgs'] auth_token: A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        :param pulumi.Input[_builtins.str] guid: The unique entity identifier of the destination in New Relic.
        :param pulumi.Input[_builtins.str] last_sent: The last time a notification was sent.
        :param pulumi.Input[_builtins.str] name: The name of the destination.
        :param pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]] properties: A nested block that describes a notification destination property. See Nested property blocks below for details.
        :param pulumi.Input['NotificationDestinationSecureUrlArgs'] secure_url: A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        :param pulumi.Input[_builtins.str] status: The status of the destination.
        :param pulumi.Input[_builtins.str] type: The type of destination.  One of: `EMAIL`, `SERVICE_NOW`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `PAGERDUTY_ACCOUNT_INTEGRATION` or `PAGERDUTY_SERVICE_INTEGRATION`, `MICROSOFT_TEAMS`, `WORKFLOW_AUTOMATION`. The types `SLACK` and `SLACK_COLLABORATION` can only be imported, updated and destroyed (cannot be created via terraform).
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if active is not None:
            pulumi.set(__self__, "active", active)
        if auth_basic is not None:
            pulumi.set(__self__, "auth_basic", auth_basic)
        if auth_custom_headers is not None:
            pulumi.set(__self__, "auth_custom_headers", auth_custom_headers)
        if auth_token is not None:
            pulumi.set(__self__, "auth_token", auth_token)
        if guid is not None:
            pulumi.set(__self__, "guid", guid)
        if last_sent is not None:
            pulumi.set(__self__, "last_sent", last_sent)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if secure_url is not None:
            pulumi.set(__self__, "secure_url", secure_url)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the destination is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter(name="authBasic")
    def auth_basic(self) -> Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']]:
        """
        A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        """
        return pulumi.get(self, "auth_basic")

    @auth_basic.setter
    def auth_basic(self, value: Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']]):
        pulumi.set(self, "auth_basic", value)

    @_builtins.property
    @pulumi.getter(name="authCustomHeaders")
    def auth_custom_headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]]:
        """
        A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        """
        return pulumi.get(self, "auth_custom_headers")

    @auth_custom_headers.setter
    def auth_custom_headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]]):
        pulumi.set(self, "auth_custom_headers", value)

    @_builtins.property
    @pulumi.getter(name="authToken")
    def auth_token(self) -> Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']]:
        """
        A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        """
        return pulumi.get(self, "auth_token")

    @auth_token.setter
    def auth_token(self, value: Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']]):
        pulumi.set(self, "auth_token", value)

    @_builtins.property
    @pulumi.getter
    def guid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique entity identifier of the destination in New Relic.
        """
        return pulumi.get(self, "guid")

    @guid.setter
    def guid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "guid", value)

    @_builtins.property
    @pulumi.getter(name="lastSent")
    def last_sent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The last time a notification was sent.
        """
        return pulumi.get(self, "last_sent")

    @last_sent.setter
    def last_sent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_sent", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the destination.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]]]:
        """
        A nested block that describes a notification destination property. See Nested property blocks below for details.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]]]):
        pulumi.set(self, "properties", value)

    @_builtins.property
    @pulumi.getter(name="secureUrl")
    def secure_url(self) -> Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']]:
        """
        A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        """
        return pulumi.get(self, "secure_url")

    @secure_url.setter
    def secure_url(self, value: Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']]):
        pulumi.set(self, "secure_url", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the destination.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of destination.  One of: `EMAIL`, `SERVICE_NOW`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `PAGERDUTY_ACCOUNT_INTEGRATION` or `PAGERDUTY_SERVICE_INTEGRATION`, `MICROSOFT_TEAMS`, `WORKFLOW_AUTOMATION`. The types `SLACK` and `SLACK_COLLABORATION` can only be imported, updated and destroyed (cannot be created via terraform).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("newrelic:index/notificationDestination:NotificationDestination")
class NotificationDestination(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_basic: Optional[pulumi.Input[Union['NotificationDestinationAuthBasicArgs', 'NotificationDestinationAuthBasicArgsDict']]] = None,
                 auth_custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationAuthCustomHeaderArgs', 'NotificationDestinationAuthCustomHeaderArgsDict']]]]] = None,
                 auth_token: Optional[pulumi.Input[Union['NotificationDestinationAuthTokenArgs', 'NotificationDestinationAuthTokenArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 properties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationPropertyArgs', 'NotificationDestinationPropertyArgsDict']]]]] = None,
                 secure_url: Optional[pulumi.Input[Union['NotificationDestinationSecureUrlArgs', 'NotificationDestinationSecureUrlArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to create and manage New Relic notification destinations. Details regarding supported products and permissions can be found [here](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/destinations).

        ## Example Usage

        ##### [Webhook](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#webhook)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="foo",
            type="WEBHOOK",
            secure_url={
                "prefix": "https://webhook.mywebhook.com/",
                "secure_suffix": "service_id/123456",
            },
            properties=[{
                "key": "source",
                "value": "terraform",
            }],
            auth_custom_headers=[{
                "key": "API_KEY",
                "value": "test-api-key",
            }])
        ```
        See additional examples.

        ## Additional Examples

        > **NOTE:** We support all properties. The mentioned properties are just an example.

        #### [WORKFLOW_AUTOMATION]

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="workflow-automation-destination-name",
            type="WORKFLOW_AUTOMATION",
            properties=[{
                "key": "",
                "value": "",
            }],
            auth_custom_headers=[{
                "key": "Api-Key",
                "value": "YOUR_NR_USER_API_KEY",
            }])
        ```

        ##### [MICROSOFT_TEAMS](https://docs.newrelic.com/docs/alerts/get-notified/microsoft-teams-integrations/)

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="ms-teams-example",
            type="MICROSOFT_TEAMS",
            properties=[{
                "key": "securityCode",
                "value": "abcdefgh",
            }])
        ```

        ##### [ServiceNow](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#servicenow)

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="servicenow-example",
            type="SERVICE_NOW",
            properties=[
                {
                    "key": "url",
                    "value": "https://service-now.com/",
                },
                {
                    "key": "two_way_integration",
                    "value": "true",
                },
            ],
            auth_basic={
                "user": "username",
                "password": "password",
            })
        ```

        ##### [Email](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#email)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="email-example",
            type="EMAIL",
            properties=[{
                "key": "email",
                "value": "email@email.com,email2@email.com",
            }])
        ```

        ##### [Jira](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#jira)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="jira-example",
            type="JIRA",
            properties=[{
                "key": "url",
                "value": "https://example.atlassian.net",
            }],
            auth_basic={
                "user": "example@email.com",
                "password": "password",
            })
        ```

        ##### [PagerDuty with service integration](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#pagerduty-sli)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="pagerduty-service-example",
            type="PAGERDUTY_SERVICE_INTEGRATION",
            properties=[{
                "key": "",
                "value": "",
            }],
            auth_token={
                "prefix": "Token token=",
                "token": "10567a689d984d03c021034b22a789e2",
            })
        ```

        ##### [PagerDuty with account integration](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#pagerduty-ali)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="pagerduty-account-example",
            type="PAGERDUTY_ACCOUNT_INTEGRATION",
            properties=[{
                "key": "two_way_integration",
                "value": "true",
            }],
            auth_token={
                "prefix": "Token token=",
                "token": "u+E8EU3MhsZwLfZ1ic1A",
            })
        ```

        #### Mobile Push
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="mobile-push-example",
            type="MOBILE_PUSH",
            properties=[{
                "key": "userId",
                "value": "12345678",
            }])
        ```

        #### [AWS Event Bridge](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#eventBridge)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="event-bridge-example",
            type="EVENT_BRIDGE",
            properties=[
                {
                    "key": "AWSAccountId",
                    "value": "123456789123456",
                },
                {
                    "key": "AWSRegion",
                    "value": "us-east-2",
                },
            ])
        ```

        #### [Slack](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#slack)

        In order to create a Slack destination, you have to grant our application access to your workspace. This process is [based on OAuth](https://api.slack.com/authentication/oauth-v2) and can only be done through a browser.
        As a result, you cannot set up a Slack destination purely with Terraform code.
        However, if you would like to use Slack-based destinations with other resources in the New Relic Terraform Provider, the data source `NotificationDestination` may be used to fetch the ID of the destination; alternatively, you might want to source the ID of the destination from  NerdGraph, or from the New Relic One UI.

        ## Additional Information

        More information about destinations integrations can be found in NewRelic [documentation](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/).
        More details about the destinations API can be found [here](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-destinations).

        ### Moving from Legacy Alert Channels to Notification Channels
        As stated in the documentation of this resource and `NotificationChannel`, destinations, created using the resource `NotificationDestination` can be paired with `NotificationChannel` to set up channels. These resources combined, are an alternative to the legacy resource `AlertChannel`, which is **deprecated** and will be **removed in a future major release**, as stated in the documentation of the resource.

        If you're currently using `AlertChannel` to manage channels, we **strongly recommend** migrating to these notifications-based resources at the earliest.

        Please refer to the examples in this page, or this example for illustrations on setting up channels with these resources.

        ## Import

        > **WARNING:** Slack-based destinations can only be imported and destroyed; this resource **does not** support creating and updating Slack-based destinations, owing to the reasons stated above, under the **Slack** section.

        Destination id can be found in the Destinations page > three dots at the right of the chosen destination > copy destination id to clipboard.
        This example is especially useful for slack destinations which *must* be imported.

        1. Add an empty resource to your terraform file:
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo")
        ```
        2. Run import command: `terraform import newrelic_notification_destination.foo <destination_id>`
        3. Run the following command after the import successfully done and copy the information to your resource:
           `terraform state show newrelic_notification_destination.foo`
        4. Add `ignore_changes` attribute on `all` in your imported resource:


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.bool] active: Indicates whether the destination is active.
        :param pulumi.Input[Union['NotificationDestinationAuthBasicArgs', 'NotificationDestinationAuthBasicArgsDict']] auth_basic: A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationAuthCustomHeaderArgs', 'NotificationDestinationAuthCustomHeaderArgsDict']]]] auth_custom_headers: A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        :param pulumi.Input[Union['NotificationDestinationAuthTokenArgs', 'NotificationDestinationAuthTokenArgsDict']] auth_token: A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        :param pulumi.Input[_builtins.str] name: The name of the destination.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationPropertyArgs', 'NotificationDestinationPropertyArgsDict']]]] properties: A nested block that describes a notification destination property. See Nested property blocks below for details.
        :param pulumi.Input[Union['NotificationDestinationSecureUrlArgs', 'NotificationDestinationSecureUrlArgsDict']] secure_url: A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        :param pulumi.Input[_builtins.str] type: The type of destination.  One of: `EMAIL`, `SERVICE_NOW`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `PAGERDUTY_ACCOUNT_INTEGRATION` or `PAGERDUTY_SERVICE_INTEGRATION`, `MICROSOFT_TEAMS`, `WORKFLOW_AUTOMATION`. The types `SLACK` and `SLACK_COLLABORATION` can only be imported, updated and destroyed (cannot be created via terraform).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NotificationDestinationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create and manage New Relic notification destinations. Details regarding supported products and permissions can be found [here](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/destinations).

        ## Example Usage

        ##### [Webhook](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#webhook)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="foo",
            type="WEBHOOK",
            secure_url={
                "prefix": "https://webhook.mywebhook.com/",
                "secure_suffix": "service_id/123456",
            },
            properties=[{
                "key": "source",
                "value": "terraform",
            }],
            auth_custom_headers=[{
                "key": "API_KEY",
                "value": "test-api-key",
            }])
        ```
        See additional examples.

        ## Additional Examples

        > **NOTE:** We support all properties. The mentioned properties are just an example.

        #### [WORKFLOW_AUTOMATION]

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="workflow-automation-destination-name",
            type="WORKFLOW_AUTOMATION",
            properties=[{
                "key": "",
                "value": "",
            }],
            auth_custom_headers=[{
                "key": "Api-Key",
                "value": "YOUR_NR_USER_API_KEY",
            }])
        ```

        ##### [MICROSOFT_TEAMS](https://docs.newrelic.com/docs/alerts/get-notified/microsoft-teams-integrations/)

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="ms-teams-example",
            type="MICROSOFT_TEAMS",
            properties=[{
                "key": "securityCode",
                "value": "abcdefgh",
            }])
        ```

        ##### [ServiceNow](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#servicenow)

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="servicenow-example",
            type="SERVICE_NOW",
            properties=[
                {
                    "key": "url",
                    "value": "https://service-now.com/",
                },
                {
                    "key": "two_way_integration",
                    "value": "true",
                },
            ],
            auth_basic={
                "user": "username",
                "password": "password",
            })
        ```

        ##### [Email](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#email)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="email-example",
            type="EMAIL",
            properties=[{
                "key": "email",
                "value": "email@email.com,email2@email.com",
            }])
        ```

        ##### [Jira](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#jira)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="jira-example",
            type="JIRA",
            properties=[{
                "key": "url",
                "value": "https://example.atlassian.net",
            }],
            auth_basic={
                "user": "example@email.com",
                "password": "password",
            })
        ```

        ##### [PagerDuty with service integration](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#pagerduty-sli)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="pagerduty-service-example",
            type="PAGERDUTY_SERVICE_INTEGRATION",
            properties=[{
                "key": "",
                "value": "",
            }],
            auth_token={
                "prefix": "Token token=",
                "token": "10567a689d984d03c021034b22a789e2",
            })
        ```

        ##### [PagerDuty with account integration](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#pagerduty-ali)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="pagerduty-account-example",
            type="PAGERDUTY_ACCOUNT_INTEGRATION",
            properties=[{
                "key": "two_way_integration",
                "value": "true",
            }],
            auth_token={
                "prefix": "Token token=",
                "token": "u+E8EU3MhsZwLfZ1ic1A",
            })
        ```

        #### Mobile Push
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="mobile-push-example",
            type="MOBILE_PUSH",
            properties=[{
                "key": "userId",
                "value": "12345678",
            }])
        ```

        #### [AWS Event Bridge](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#eventBridge)
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo",
            account_id="12345678",
            name="event-bridge-example",
            type="EVENT_BRIDGE",
            properties=[
                {
                    "key": "AWSAccountId",
                    "value": "123456789123456",
                },
                {
                    "key": "AWSRegion",
                    "value": "us-east-2",
                },
            ])
        ```

        #### [Slack](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/#slack)

        In order to create a Slack destination, you have to grant our application access to your workspace. This process is [based on OAuth](https://api.slack.com/authentication/oauth-v2) and can only be done through a browser.
        As a result, you cannot set up a Slack destination purely with Terraform code.
        However, if you would like to use Slack-based destinations with other resources in the New Relic Terraform Provider, the data source `NotificationDestination` may be used to fetch the ID of the destination; alternatively, you might want to source the ID of the destination from  NerdGraph, or from the New Relic One UI.

        ## Additional Information

        More information about destinations integrations can be found in NewRelic [documentation](https://docs.newrelic.com/docs/alerts-applied-intelligence/notifications/notification-integrations/).
        More details about the destinations API can be found [here](https://docs.newrelic.com/docs/apis/nerdgraph/examples/nerdgraph-api-notifications-destinations).

        ### Moving from Legacy Alert Channels to Notification Channels
        As stated in the documentation of this resource and `NotificationChannel`, destinations, created using the resource `NotificationDestination` can be paired with `NotificationChannel` to set up channels. These resources combined, are an alternative to the legacy resource `AlertChannel`, which is **deprecated** and will be **removed in a future major release**, as stated in the documentation of the resource.

        If you're currently using `AlertChannel` to manage channels, we **strongly recommend** migrating to these notifications-based resources at the earliest.

        Please refer to the examples in this page, or this example for illustrations on setting up channels with these resources.

        ## Import

        > **WARNING:** Slack-based destinations can only be imported and destroyed; this resource **does not** support creating and updating Slack-based destinations, owing to the reasons stated above, under the **Slack** section.

        Destination id can be found in the Destinations page > three dots at the right of the chosen destination > copy destination id to clipboard.
        This example is especially useful for slack destinations which *must* be imported.

        1. Add an empty resource to your terraform file:
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.NotificationDestination("foo")
        ```
        2. Run import command: `terraform import newrelic_notification_destination.foo <destination_id>`
        3. Run the following command after the import successfully done and copy the information to your resource:
           `terraform state show newrelic_notification_destination.foo`
        4. Add `ignore_changes` attribute on `all` in your imported resource:


        :param str resource_name: The name of the resource.
        :param NotificationDestinationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NotificationDestinationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_basic: Optional[pulumi.Input[Union['NotificationDestinationAuthBasicArgs', 'NotificationDestinationAuthBasicArgsDict']]] = None,
                 auth_custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationAuthCustomHeaderArgs', 'NotificationDestinationAuthCustomHeaderArgsDict']]]]] = None,
                 auth_token: Optional[pulumi.Input[Union['NotificationDestinationAuthTokenArgs', 'NotificationDestinationAuthTokenArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 properties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationPropertyArgs', 'NotificationDestinationPropertyArgsDict']]]]] = None,
                 secure_url: Optional[pulumi.Input[Union['NotificationDestinationSecureUrlArgs', 'NotificationDestinationSecureUrlArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NotificationDestinationArgs.__new__(NotificationDestinationArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["active"] = active
            __props__.__dict__["auth_basic"] = auth_basic
            __props__.__dict__["auth_custom_headers"] = auth_custom_headers
            __props__.__dict__["auth_token"] = auth_token
            __props__.__dict__["name"] = name
            if properties is None and not opts.urn:
                raise TypeError("Missing required property 'properties'")
            __props__.__dict__["properties"] = properties
            __props__.__dict__["secure_url"] = secure_url
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["guid"] = None
            __props__.__dict__["last_sent"] = None
            __props__.__dict__["status"] = None
        super(NotificationDestination, __self__).__init__(
            'newrelic:index/notificationDestination:NotificationDestination',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            active: Optional[pulumi.Input[_builtins.bool]] = None,
            auth_basic: Optional[pulumi.Input[Union['NotificationDestinationAuthBasicArgs', 'NotificationDestinationAuthBasicArgsDict']]] = None,
            auth_custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationAuthCustomHeaderArgs', 'NotificationDestinationAuthCustomHeaderArgsDict']]]]] = None,
            auth_token: Optional[pulumi.Input[Union['NotificationDestinationAuthTokenArgs', 'NotificationDestinationAuthTokenArgsDict']]] = None,
            guid: Optional[pulumi.Input[_builtins.str]] = None,
            last_sent: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            properties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationPropertyArgs', 'NotificationDestinationPropertyArgsDict']]]]] = None,
            secure_url: Optional[pulumi.Input[Union['NotificationDestinationSecureUrlArgs', 'NotificationDestinationSecureUrlArgsDict']]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'NotificationDestination':
        """
        Get an existing NotificationDestination resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.bool] active: Indicates whether the destination is active.
        :param pulumi.Input[Union['NotificationDestinationAuthBasicArgs', 'NotificationDestinationAuthBasicArgsDict']] auth_basic: A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationAuthCustomHeaderArgs', 'NotificationDestinationAuthCustomHeaderArgsDict']]]] auth_custom_headers: A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        :param pulumi.Input[Union['NotificationDestinationAuthTokenArgs', 'NotificationDestinationAuthTokenArgsDict']] auth_token: A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        :param pulumi.Input[_builtins.str] guid: The unique entity identifier of the destination in New Relic.
        :param pulumi.Input[_builtins.str] last_sent: The last time a notification was sent.
        :param pulumi.Input[_builtins.str] name: The name of the destination.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationPropertyArgs', 'NotificationDestinationPropertyArgsDict']]]] properties: A nested block that describes a notification destination property. See Nested property blocks below for details.
        :param pulumi.Input[Union['NotificationDestinationSecureUrlArgs', 'NotificationDestinationSecureUrlArgsDict']] secure_url: A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        :param pulumi.Input[_builtins.str] status: The status of the destination.
        :param pulumi.Input[_builtins.str] type: The type of destination.  One of: `EMAIL`, `SERVICE_NOW`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `PAGERDUTY_ACCOUNT_INTEGRATION` or `PAGERDUTY_SERVICE_INTEGRATION`, `MICROSOFT_TEAMS`, `WORKFLOW_AUTOMATION`. The types `SLACK` and `SLACK_COLLABORATION` can only be imported, updated and destroyed (cannot be created via terraform).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NotificationDestinationState.__new__(_NotificationDestinationState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["active"] = active
        __props__.__dict__["auth_basic"] = auth_basic
        __props__.__dict__["auth_custom_headers"] = auth_custom_headers
        __props__.__dict__["auth_token"] = auth_token
        __props__.__dict__["guid"] = guid
        __props__.__dict__["last_sent"] = last_sent
        __props__.__dict__["name"] = name
        __props__.__dict__["properties"] = properties
        __props__.__dict__["secure_url"] = secure_url
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return NotificationDestination(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def active(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates whether the destination is active.
        """
        return pulumi.get(self, "active")

    @_builtins.property
    @pulumi.getter(name="authBasic")
    def auth_basic(self) -> pulumi.Output[Optional['outputs.NotificationDestinationAuthBasic']]:
        """
        A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        """
        return pulumi.get(self, "auth_basic")

    @_builtins.property
    @pulumi.getter(name="authCustomHeaders")
    def auth_custom_headers(self) -> pulumi.Output[Optional[Sequence['outputs.NotificationDestinationAuthCustomHeader']]]:
        """
        A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        """
        return pulumi.get(self, "auth_custom_headers")

    @_builtins.property
    @pulumi.getter(name="authToken")
    def auth_token(self) -> pulumi.Output[Optional['outputs.NotificationDestinationAuthToken']]:
        """
        A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        """
        return pulumi.get(self, "auth_token")

    @_builtins.property
    @pulumi.getter
    def guid(self) -> pulumi.Output[_builtins.str]:
        """
        The unique entity identifier of the destination in New Relic.
        """
        return pulumi.get(self, "guid")

    @_builtins.property
    @pulumi.getter(name="lastSent")
    def last_sent(self) -> pulumi.Output[_builtins.str]:
        """
        The last time a notification was sent.
        """
        return pulumi.get(self, "last_sent")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the destination.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def properties(self) -> pulumi.Output[Sequence['outputs.NotificationDestinationProperty']]:
        """
        A nested block that describes a notification destination property. See Nested property blocks below for details.
        """
        return pulumi.get(self, "properties")

    @_builtins.property
    @pulumi.getter(name="secureUrl")
    def secure_url(self) -> pulumi.Output[Optional['outputs.NotificationDestinationSecureUrl']]:
        """
        A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        """
        return pulumi.get(self, "secure_url")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the destination.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of destination.  One of: `EMAIL`, `SERVICE_NOW`, `SERVICE_NOW_APP`, `WEBHOOK`, `JIRA`, `MOBILE_PUSH`, `EVENT_BRIDGE`, `PAGERDUTY_ACCOUNT_INTEGRATION` or `PAGERDUTY_SERVICE_INTEGRATION`, `MICROSOFT_TEAMS`, `WORKFLOW_AUTOMATION`. The types `SLACK` and `SLACK_COLLABORATION` can only be imported, updated and destroyed (cannot be created via terraform).
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AlertCompoundConditionArgs', 'AlertCompoundCondition']

@pulumi.input_type
class AlertCompoundConditionArgs:
    def __init__(__self__, *,
                 component_conditions: pulumi.Input[Sequence[pulumi.Input['AlertCompoundConditionComponentConditionArgs']]],
                 enabled: pulumi.Input[_builtins.bool],
                 policy_id: pulumi.Input[_builtins.str],
                 trigger_expression: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 facet_matching_behavior: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 runbook_url: Optional[pulumi.Input[_builtins.str]] = None,
                 threshold_duration: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a AlertCompoundCondition resource.

        :param pulumi.Input[Sequence[pulumi.Input['AlertCompoundConditionComponentConditionArgs']]] component_conditions: The list of conditions to be combined. Each component condition must be enabled. Must include at least 2. See Component Conditions below for details.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not the compound alert condition is enabled. Defaults to `true`.
        :param pulumi.Input[_builtins.str] policy_id: The ID of the policy where this alert compound condition should be used.
        :param pulumi.Input[_builtins.str] trigger_expression: Expression that defines how component condition evaluations are combined. Valid operators are 'AND', 'OR', 'NOT'. For more complex expressions, use parentheses. Use the aliases from `component_conditions` to build expressions like `"A AND B"`, `"A OR B"`, `"(A AND B) OR C"`, or `"A AND (B OR C) AND NOT (D AND E)"`.
        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID for managing your compound alert conditions. Defaults to the account ID set in your environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input[_builtins.str] facet_matching_behavior: How the compound condition will take into account the component conditions' facets during evaluation. Valid values are:
               - `FACETS_IGNORED` - (Default) Facets are not taken into consideration when determining when the compound alert condition activates
               - `FACETS_MATCH` - The compound alert condition will activate only when shared facets have matching values
        :param pulumi.Input[_builtins.str] name: The title of the compound alert condition.
        :param pulumi.Input[_builtins.str] runbook_url: Runbook URL to display in notifications.
        :param pulumi.Input[_builtins.int] threshold_duration: The duration, in seconds, that the trigger expression must be true before the compound alert condition will activate. Between 30-86400 seconds.
        """
        pulumi.set(__self__, "component_conditions", component_conditions)
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "policy_id", policy_id)
        pulumi.set(__self__, "trigger_expression", trigger_expression)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if facet_matching_behavior is not None:
            pulumi.set(__self__, "facet_matching_behavior", facet_matching_behavior)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if runbook_url is not None:
            pulumi.set(__self__, "runbook_url", runbook_url)
        if threshold_duration is not None:
            pulumi.set(__self__, "threshold_duration", threshold_duration)

    @_builtins.property
    @pulumi.getter(name="componentConditions")
    def component_conditions(self) -> pulumi.Input[Sequence[pulumi.Input['AlertCompoundConditionComponentConditionArgs']]]:
        """
        The list of conditions to be combined. Each component condition must be enabled. Must include at least 2. See Component Conditions below for details.
        """
        return pulumi.get(self, "component_conditions")

    @component_conditions.setter
    def component_conditions(self, value: pulumi.Input[Sequence[pulumi.Input['AlertCompoundConditionComponentConditionArgs']]]):
        pulumi.set(self, "component_conditions", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Whether or not the compound alert condition is enabled. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the policy where this alert compound condition should be used.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter(name="triggerExpression")
    def trigger_expression(self) -> pulumi.Input[_builtins.str]:
        """
        Expression that defines how component condition evaluations are combined. Valid operators are 'AND', 'OR', 'NOT'. For more complex expressions, use parentheses. Use the aliases from `component_conditions` to build expressions like `"A AND B"`, `"A OR B"`, `"(A AND B) OR C"`, or `"A AND (B OR C) AND NOT (D AND E)"`.
        """
        return pulumi.get(self, "trigger_expression")

    @trigger_expression.setter
    def trigger_expression(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "trigger_expression", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The New Relic account ID for managing your compound alert conditions. Defaults to the account ID set in your environment variable `NEW_RELIC_ACCOUNT_ID`.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="facetMatchingBehavior")
    def facet_matching_behavior(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        How the compound condition will take into account the component conditions' facets during evaluation. Valid values are:
        - `FACETS_IGNORED` - (Default) Facets are not taken into consideration when determining when the compound alert condition activates
        - `FACETS_MATCH` - The compound alert condition will activate only when shared facets have matching values
        """
        return pulumi.get(self, "facet_matching_behavior")

    @facet_matching_behavior.setter
    def facet_matching_behavior(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "facet_matching_behavior", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The title of the compound alert condition.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="runbookUrl")
    def runbook_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Runbook URL to display in notifications.
        """
        return pulumi.get(self, "runbook_url")

    @runbook_url.setter
    def runbook_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "runbook_url", value)

    @_builtins.property
    @pulumi.getter(name="thresholdDuration")
    def threshold_duration(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The duration, in seconds, that the trigger expression must be true before the compound alert condition will activate. Between 30-86400 seconds.
        """
        return pulumi.get(self, "threshold_duration")

    @threshold_duration.setter
    def threshold_duration(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "threshold_duration", value)


@pulumi.input_type
class _AlertCompoundConditionState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 component_conditions: Optional[pulumi.Input[Sequence[pulumi.Input['AlertCompoundConditionComponentConditionArgs']]]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 facet_matching_behavior: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 runbook_url: Optional[pulumi.Input[_builtins.str]] = None,
                 threshold_duration: Optional[pulumi.Input[_builtins.int]] = None,
                 trigger_expression: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AlertCompoundCondition resources.

        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID for managing your compound alert conditions. Defaults to the account ID set in your environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input[Sequence[pulumi.Input['AlertCompoundConditionComponentConditionArgs']]] component_conditions: The list of conditions to be combined. Each component condition must be enabled. Must include at least 2. See Component Conditions below for details.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not the compound alert condition is enabled. Defaults to `true`.
        :param pulumi.Input[_builtins.str] facet_matching_behavior: How the compound condition will take into account the component conditions' facets during evaluation. Valid values are:
               - `FACETS_IGNORED` - (Default) Facets are not taken into consideration when determining when the compound alert condition activates
               - `FACETS_MATCH` - The compound alert condition will activate only when shared facets have matching values
        :param pulumi.Input[_builtins.str] name: The title of the compound alert condition.
        :param pulumi.Input[_builtins.str] policy_id: The ID of the policy where this alert compound condition should be used.
        :param pulumi.Input[_builtins.str] runbook_url: Runbook URL to display in notifications.
        :param pulumi.Input[_builtins.int] threshold_duration: The duration, in seconds, that the trigger expression must be true before the compound alert condition will activate. Between 30-86400 seconds.
        :param pulumi.Input[_builtins.str] trigger_expression: Expression that defines how component condition evaluations are combined. Valid operators are 'AND', 'OR', 'NOT'. For more complex expressions, use parentheses. Use the aliases from `component_conditions` to build expressions like `"A AND B"`, `"A OR B"`, `"(A AND B) OR C"`, or `"A AND (B OR C) AND NOT (D AND E)"`.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if component_conditions is not None:
            pulumi.set(__self__, "component_conditions", component_conditions)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if facet_matching_behavior is not None:
            pulumi.set(__self__, "facet_matching_behavior", facet_matching_behavior)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if runbook_url is not None:
            pulumi.set(__self__, "runbook_url", runbook_url)
        if threshold_duration is not None:
            pulumi.set(__self__, "threshold_duration", threshold_duration)
        if trigger_expression is not None:
            pulumi.set(__self__, "trigger_expression", trigger_expression)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The New Relic account ID for managing your compound alert conditions. Defaults to the account ID set in your environment variable `NEW_RELIC_ACCOUNT_ID`.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="componentConditions")
    def component_conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AlertCompoundConditionComponentConditionArgs']]]]:
        """
        The list of conditions to be combined. Each component condition must be enabled. Must include at least 2. See Component Conditions below for details.
        """
        return pulumi.get(self, "component_conditions")

    @component_conditions.setter
    def component_conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AlertCompoundConditionComponentConditionArgs']]]]):
        pulumi.set(self, "component_conditions", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not the compound alert condition is enabled. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="facetMatchingBehavior")
    def facet_matching_behavior(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        How the compound condition will take into account the component conditions' facets during evaluation. Valid values are:
        - `FACETS_IGNORED` - (Default) Facets are not taken into consideration when determining when the compound alert condition activates
        - `FACETS_MATCH` - The compound alert condition will activate only when shared facets have matching values
        """
        return pulumi.get(self, "facet_matching_behavior")

    @facet_matching_behavior.setter
    def facet_matching_behavior(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "facet_matching_behavior", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The title of the compound alert condition.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the policy where this alert compound condition should be used.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter(name="runbookUrl")
    def runbook_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Runbook URL to display in notifications.
        """
        return pulumi.get(self, "runbook_url")

    @runbook_url.setter
    def runbook_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "runbook_url", value)

    @_builtins.property
    @pulumi.getter(name="thresholdDuration")
    def threshold_duration(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The duration, in seconds, that the trigger expression must be true before the compound alert condition will activate. Between 30-86400 seconds.
        """
        return pulumi.get(self, "threshold_duration")

    @threshold_duration.setter
    def threshold_duration(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "threshold_duration", value)

    @_builtins.property
    @pulumi.getter(name="triggerExpression")
    def trigger_expression(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Expression that defines how component condition evaluations are combined. Valid operators are 'AND', 'OR', 'NOT'. For more complex expressions, use parentheses. Use the aliases from `component_conditions` to build expressions like `"A AND B"`, `"A OR B"`, `"(A AND B) OR C"`, or `"A AND (B OR C) AND NOT (D AND E)"`.
        """
        return pulumi.get(self, "trigger_expression")

    @trigger_expression.setter
    def trigger_expression(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "trigger_expression", value)


@pulumi.type_token("newrelic:index/alertCompoundCondition:AlertCompoundCondition")
class AlertCompoundCondition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 component_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AlertCompoundConditionComponentConditionArgs', 'AlertCompoundConditionComponentConditionArgsDict']]]]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 facet_matching_behavior: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 runbook_url: Optional[pulumi.Input[_builtins.str]] = None,
                 threshold_duration: Optional[pulumi.Input[_builtins.int]] = None,
                 trigger_expression: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to create and manage compound alert conditions in New Relic. Compound conditions allow you to combine multiple alert conditions using logical expressions (AND, OR, NOT) to create more sophisticated alerting logic.

        ## Example Usage

        ### Basic Compound Condition (AND)

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        example = newrelic.AlertPolicy("example", name="my-policy")
        # Create component NRQL conditions
        high_response_time = newrelic.NrqlAlertCondition("high_response_time",
            policy_id=example.id,
            name="High Response Time",
            enabled=True,
            nrql={
                "query": "SELECT average(duration) FROM Transaction WHERE appName = 'MyApp'",
            },
            critical={
                "operator": "above",
                "threshold": 5,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        high_error_rate = newrelic.NrqlAlertCondition("high_error_rate",
            policy_id=example.id,
            name="High Error Rate",
            enabled=True,
            nrql={
                "query": "SELECT percentage(count(*), WHERE error IS true) FROM Transaction WHERE appName = 'MyApp'",
            },
            critical={
                "operator": "above",
                "threshold": 5,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        # Create alert compound condition combining both
        critical_service_health = newrelic.AlertCompoundCondition("critical_service_health",
            policy_id=example.id,
            name="Critical Service Health",
            enabled=True,
            trigger_expression="A AND B",
            runbook_url="https://example.com/runbooks/critical-health",
            threshold_duration=120,
            component_conditions=[
                {
                    "id": high_response_time.id,
                    "alias": "A",
                },
                {
                    "id": high_error_rate.id,
                    "alias": "B",
                },
            ],
            facet_matching_behavior="FACETS_IGNORED")
        ```

        ### Complex Condition with Three Components

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        high_cpu = newrelic.NrqlAlertCondition("high_cpu",
            policy_id=example["id"],
            name="High CPU",
            enabled=True,
            nrql={
                "query": "SELECT average(cpuPercent) FROM SystemSample WHERE hostname = 'myhost'",
            },
            critical={
                "operator": "above",
                "threshold": 80,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        high_memory = newrelic.NrqlAlertCondition("high_memory",
            policy_id=example["id"],
            name="High Memory",
            enabled=True,
            nrql={
                "query": "SELECT average(memoryUsedPercent) FROM SystemSample WHERE hostname = 'myhost'",
            },
            critical={
                "operator": "above",
                "threshold": 85,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        disk_full = newrelic.NrqlAlertCondition("disk_full",
            policy_id=example["id"],
            name="Disk Full",
            enabled=True,
            nrql={
                "query": "SELECT average(diskUsedPercent) FROM SystemSample WHERE hostname = 'myhost'",
            },
            critical={
                "operator": "above",
                "threshold": 90,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        complex = newrelic.AlertCompoundCondition("complex",
            policy_id=example["id"],
            name="Complex Infrastructure Alert",
            enabled=True,
            trigger_expression="(A AND B) OR C",
            component_conditions=[
                {
                    "id": high_cpu.id,
                    "alias": "A",
                },
                {
                    "id": high_memory.id,
                    "alias": "B",
                },
                {
                    "id": disk_full.id,
                    "alias": "C",
                },
            ])
        ```

        ### With Facet Matching

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        high_throughput_per_host = newrelic.NrqlAlertCondition("high_throughput_per_host",
            policy_id=example["id"],
            name="High Throughput Per Host",
            enabled=True,
            nrql={
                "query": "SELECT rate(count(*), 1 minute) FROM Transaction FACET host",
            },
            critical={
                "operator": "above",
                "threshold": 1000,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        high_error_rate_per_host = newrelic.NrqlAlertCondition("high_error_rate_per_host",
            policy_id=example["id"],
            name="High Error Rate Per Host",
            enabled=True,
            nrql={
                "query": "SELECT percentage(count(*), WHERE error IS true) FROM Transaction FACET host",
            },
            critical={
                "operator": "above",
                "threshold": 5,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        with_facets = newrelic.AlertCompoundCondition("with_facets",
            policy_id=example["id"],
            name="Host-Specific Alert",
            enabled=True,
            trigger_expression="A AND B",
            facet_matching_behavior="FACETS_MATCH",
            component_conditions=[
                {
                    "id": high_throughput_per_host.id,
                    "alias": "A",
                },
                {
                    "id": high_error_rate_per_host.id,
                    "alias": "B",
                },
            ])
        ```

        ## Additional Information

        ### Understanding Trigger Expressions

        Trigger expressions define the logical conditions under which your alert compound condition will activate. Valid operators are:

        - **AND** - Both conditions must be true
        - **OR** - Either condition must be true
        - **NOT** - Negates a condition
        - **Parentheses** - Group conditions for complex logic

        Examples:

        - `"A AND B"` - Activate when both A and B are in violation
        - `"A OR B"` - Activate when either A or B is in violation
        - `"A AND NOT B"` - Activate when A is in violation but B is not
        - `"(A AND B) OR C"` - Activate when both A and B are in violation, OR when C is in violation
        - `"A AND (B OR C) AND NOT D"` - Activate when A is in violation AND either B or C is in violation AND D is not in violation

        ### Facet Matching Behavior

        When your component NRQL conditions use FACET clauses:

        - **FACETS_IGNORED** (Default) - Facets are not taken into consideration when determining when the compound alert condition activates. If component conditions have violations (on any facet), the compound alert condition will activate based on the trigger expression.
        - **FACETS_MATCH** - The compound alert condition will activate only when shared facets have matching values. For example, if condition A fires for `host="server-1"` and condition B fires for `host="server-2"`, the compound alert condition will NOT activate because the facet values don't match.

        ### Threshold Duration

        The `threshold_duration` parameter controls how long the trigger expression must remain true before the compound alert condition will activate.

        ## Import

        Compound alert conditions can be imported using the condition ID, e.g.

        ```sh
        $ pulumi import newrelic:index/alertCompoundCondition:AlertCompoundCondition main 789012
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID for managing your compound alert conditions. Defaults to the account ID set in your environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AlertCompoundConditionComponentConditionArgs', 'AlertCompoundConditionComponentConditionArgsDict']]]] component_conditions: The list of conditions to be combined. Each component condition must be enabled. Must include at least 2. See Component Conditions below for details.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not the compound alert condition is enabled. Defaults to `true`.
        :param pulumi.Input[_builtins.str] facet_matching_behavior: How the compound condition will take into account the component conditions' facets during evaluation. Valid values are:
               - `FACETS_IGNORED` - (Default) Facets are not taken into consideration when determining when the compound alert condition activates
               - `FACETS_MATCH` - The compound alert condition will activate only when shared facets have matching values
        :param pulumi.Input[_builtins.str] name: The title of the compound alert condition.
        :param pulumi.Input[_builtins.str] policy_id: The ID of the policy where this alert compound condition should be used.
        :param pulumi.Input[_builtins.str] runbook_url: Runbook URL to display in notifications.
        :param pulumi.Input[_builtins.int] threshold_duration: The duration, in seconds, that the trigger expression must be true before the compound alert condition will activate. Between 30-86400 seconds.
        :param pulumi.Input[_builtins.str] trigger_expression: Expression that defines how component condition evaluations are combined. Valid operators are 'AND', 'OR', 'NOT'. For more complex expressions, use parentheses. Use the aliases from `component_conditions` to build expressions like `"A AND B"`, `"A OR B"`, `"(A AND B) OR C"`, or `"A AND (B OR C) AND NOT (D AND E)"`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AlertCompoundConditionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create and manage compound alert conditions in New Relic. Compound conditions allow you to combine multiple alert conditions using logical expressions (AND, OR, NOT) to create more sophisticated alerting logic.

        ## Example Usage

        ### Basic Compound Condition (AND)

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        example = newrelic.AlertPolicy("example", name="my-policy")
        # Create component NRQL conditions
        high_response_time = newrelic.NrqlAlertCondition("high_response_time",
            policy_id=example.id,
            name="High Response Time",
            enabled=True,
            nrql={
                "query": "SELECT average(duration) FROM Transaction WHERE appName = 'MyApp'",
            },
            critical={
                "operator": "above",
                "threshold": 5,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        high_error_rate = newrelic.NrqlAlertCondition("high_error_rate",
            policy_id=example.id,
            name="High Error Rate",
            enabled=True,
            nrql={
                "query": "SELECT percentage(count(*), WHERE error IS true) FROM Transaction WHERE appName = 'MyApp'",
            },
            critical={
                "operator": "above",
                "threshold": 5,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        # Create alert compound condition combining both
        critical_service_health = newrelic.AlertCompoundCondition("critical_service_health",
            policy_id=example.id,
            name="Critical Service Health",
            enabled=True,
            trigger_expression="A AND B",
            runbook_url="https://example.com/runbooks/critical-health",
            threshold_duration=120,
            component_conditions=[
                {
                    "id": high_response_time.id,
                    "alias": "A",
                },
                {
                    "id": high_error_rate.id,
                    "alias": "B",
                },
            ],
            facet_matching_behavior="FACETS_IGNORED")
        ```

        ### Complex Condition with Three Components

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        high_cpu = newrelic.NrqlAlertCondition("high_cpu",
            policy_id=example["id"],
            name="High CPU",
            enabled=True,
            nrql={
                "query": "SELECT average(cpuPercent) FROM SystemSample WHERE hostname = 'myhost'",
            },
            critical={
                "operator": "above",
                "threshold": 80,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        high_memory = newrelic.NrqlAlertCondition("high_memory",
            policy_id=example["id"],
            name="High Memory",
            enabled=True,
            nrql={
                "query": "SELECT average(memoryUsedPercent) FROM SystemSample WHERE hostname = 'myhost'",
            },
            critical={
                "operator": "above",
                "threshold": 85,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        disk_full = newrelic.NrqlAlertCondition("disk_full",
            policy_id=example["id"],
            name="Disk Full",
            enabled=True,
            nrql={
                "query": "SELECT average(diskUsedPercent) FROM SystemSample WHERE hostname = 'myhost'",
            },
            critical={
                "operator": "above",
                "threshold": 90,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        complex = newrelic.AlertCompoundCondition("complex",
            policy_id=example["id"],
            name="Complex Infrastructure Alert",
            enabled=True,
            trigger_expression="(A AND B) OR C",
            component_conditions=[
                {
                    "id": high_cpu.id,
                    "alias": "A",
                },
                {
                    "id": high_memory.id,
                    "alias": "B",
                },
                {
                    "id": disk_full.id,
                    "alias": "C",
                },
            ])
        ```

        ### With Facet Matching

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        high_throughput_per_host = newrelic.NrqlAlertCondition("high_throughput_per_host",
            policy_id=example["id"],
            name="High Throughput Per Host",
            enabled=True,
            nrql={
                "query": "SELECT rate(count(*), 1 minute) FROM Transaction FACET host",
            },
            critical={
                "operator": "above",
                "threshold": 1000,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        high_error_rate_per_host = newrelic.NrqlAlertCondition("high_error_rate_per_host",
            policy_id=example["id"],
            name="High Error Rate Per Host",
            enabled=True,
            nrql={
                "query": "SELECT percentage(count(*), WHERE error IS true) FROM Transaction FACET host",
            },
            critical={
                "operator": "above",
                "threshold": 5,
                "threshold_duration": 300,
                "threshold_occurrences": "all",
            },
            violation_time_limit_seconds=3600)
        with_facets = newrelic.AlertCompoundCondition("with_facets",
            policy_id=example["id"],
            name="Host-Specific Alert",
            enabled=True,
            trigger_expression="A AND B",
            facet_matching_behavior="FACETS_MATCH",
            component_conditions=[
                {
                    "id": high_throughput_per_host.id,
                    "alias": "A",
                },
                {
                    "id": high_error_rate_per_host.id,
                    "alias": "B",
                },
            ])
        ```

        ## Additional Information

        ### Understanding Trigger Expressions

        Trigger expressions define the logical conditions under which your alert compound condition will activate. Valid operators are:

        - **AND** - Both conditions must be true
        - **OR** - Either condition must be true
        - **NOT** - Negates a condition
        - **Parentheses** - Group conditions for complex logic

        Examples:

        - `"A AND B"` - Activate when both A and B are in violation
        - `"A OR B"` - Activate when either A or B is in violation
        - `"A AND NOT B"` - Activate when A is in violation but B is not
        - `"(A AND B) OR C"` - Activate when both A and B are in violation, OR when C is in violation
        - `"A AND (B OR C) AND NOT D"` - Activate when A is in violation AND either B or C is in violation AND D is not in violation

        ### Facet Matching Behavior

        When your component NRQL conditions use FACET clauses:

        - **FACETS_IGNORED** (Default) - Facets are not taken into consideration when determining when the compound alert condition activates. If component conditions have violations (on any facet), the compound alert condition will activate based on the trigger expression.
        - **FACETS_MATCH** - The compound alert condition will activate only when shared facets have matching values. For example, if condition A fires for `host="server-1"` and condition B fires for `host="server-2"`, the compound alert condition will NOT activate because the facet values don't match.

        ### Threshold Duration

        The `threshold_duration` parameter controls how long the trigger expression must remain true before the compound alert condition will activate.

        ## Import

        Compound alert conditions can be imported using the condition ID, e.g.

        ```sh
        $ pulumi import newrelic:index/alertCompoundCondition:AlertCompoundCondition main 789012
        ```


        :param str resource_name: The name of the resource.
        :param AlertCompoundConditionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AlertCompoundConditionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 component_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AlertCompoundConditionComponentConditionArgs', 'AlertCompoundConditionComponentConditionArgsDict']]]]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 facet_matching_behavior: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 runbook_url: Optional[pulumi.Input[_builtins.str]] = None,
                 threshold_duration: Optional[pulumi.Input[_builtins.int]] = None,
                 trigger_expression: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AlertCompoundConditionArgs.__new__(AlertCompoundConditionArgs)

            __props__.__dict__["account_id"] = account_id
            if component_conditions is None and not opts.urn:
                raise TypeError("Missing required property 'component_conditions'")
            __props__.__dict__["component_conditions"] = component_conditions
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["facet_matching_behavior"] = facet_matching_behavior
            __props__.__dict__["name"] = name
            if policy_id is None and not opts.urn:
                raise TypeError("Missing required property 'policy_id'")
            __props__.__dict__["policy_id"] = policy_id
            __props__.__dict__["runbook_url"] = runbook_url
            __props__.__dict__["threshold_duration"] = threshold_duration
            if trigger_expression is None and not opts.urn:
                raise TypeError("Missing required property 'trigger_expression'")
            __props__.__dict__["trigger_expression"] = trigger_expression
        super(AlertCompoundCondition, __self__).__init__(
            'newrelic:index/alertCompoundCondition:AlertCompoundCondition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            component_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AlertCompoundConditionComponentConditionArgs', 'AlertCompoundConditionComponentConditionArgsDict']]]]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            facet_matching_behavior: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            runbook_url: Optional[pulumi.Input[_builtins.str]] = None,
            threshold_duration: Optional[pulumi.Input[_builtins.int]] = None,
            trigger_expression: Optional[pulumi.Input[_builtins.str]] = None) -> 'AlertCompoundCondition':
        """
        Get an existing AlertCompoundCondition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID for managing your compound alert conditions. Defaults to the account ID set in your environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AlertCompoundConditionComponentConditionArgs', 'AlertCompoundConditionComponentConditionArgsDict']]]] component_conditions: The list of conditions to be combined. Each component condition must be enabled. Must include at least 2. See Component Conditions below for details.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not the compound alert condition is enabled. Defaults to `true`.
        :param pulumi.Input[_builtins.str] facet_matching_behavior: How the compound condition will take into account the component conditions' facets during evaluation. Valid values are:
               - `FACETS_IGNORED` - (Default) Facets are not taken into consideration when determining when the compound alert condition activates
               - `FACETS_MATCH` - The compound alert condition will activate only when shared facets have matching values
        :param pulumi.Input[_builtins.str] name: The title of the compound alert condition.
        :param pulumi.Input[_builtins.str] policy_id: The ID of the policy where this alert compound condition should be used.
        :param pulumi.Input[_builtins.str] runbook_url: Runbook URL to display in notifications.
        :param pulumi.Input[_builtins.int] threshold_duration: The duration, in seconds, that the trigger expression must be true before the compound alert condition will activate. Between 30-86400 seconds.
        :param pulumi.Input[_builtins.str] trigger_expression: Expression that defines how component condition evaluations are combined. Valid operators are 'AND', 'OR', 'NOT'. For more complex expressions, use parentheses. Use the aliases from `component_conditions` to build expressions like `"A AND B"`, `"A OR B"`, `"(A AND B) OR C"`, or `"A AND (B OR C) AND NOT (D AND E)"`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AlertCompoundConditionState.__new__(_AlertCompoundConditionState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["component_conditions"] = component_conditions
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["facet_matching_behavior"] = facet_matching_behavior
        __props__.__dict__["name"] = name
        __props__.__dict__["policy_id"] = policy_id
        __props__.__dict__["runbook_url"] = runbook_url
        __props__.__dict__["threshold_duration"] = threshold_duration
        __props__.__dict__["trigger_expression"] = trigger_expression
        return AlertCompoundCondition(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The New Relic account ID for managing your compound alert conditions. Defaults to the account ID set in your environment variable `NEW_RELIC_ACCOUNT_ID`.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="componentConditions")
    def component_conditions(self) -> pulumi.Output[Sequence['outputs.AlertCompoundConditionComponentCondition']]:
        """
        The list of conditions to be combined. Each component condition must be enabled. Must include at least 2. See Component Conditions below for details.
        """
        return pulumi.get(self, "component_conditions")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether or not the compound alert condition is enabled. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="facetMatchingBehavior")
    def facet_matching_behavior(self) -> pulumi.Output[_builtins.str]:
        """
        How the compound condition will take into account the component conditions' facets during evaluation. Valid values are:
        - `FACETS_IGNORED` - (Default) Facets are not taken into consideration when determining when the compound alert condition activates
        - `FACETS_MATCH` - The compound alert condition will activate only when shared facets have matching values
        """
        return pulumi.get(self, "facet_matching_behavior")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The title of the compound alert condition.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the policy where this alert compound condition should be used.
        """
        return pulumi.get(self, "policy_id")

    @_builtins.property
    @pulumi.getter(name="runbookUrl")
    def runbook_url(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Runbook URL to display in notifications.
        """
        return pulumi.get(self, "runbook_url")

    @_builtins.property
    @pulumi.getter(name="thresholdDuration")
    def threshold_duration(self) -> pulumi.Output[_builtins.int]:
        """
        The duration, in seconds, that the trigger expression must be true before the compound alert condition will activate. Between 30-86400 seconds.
        """
        return pulumi.get(self, "threshold_duration")

    @_builtins.property
    @pulumi.getter(name="triggerExpression")
    def trigger_expression(self) -> pulumi.Output[_builtins.str]:
        """
        Expression that defines how component condition evaluations are combined. Valid operators are 'AND', 'OR', 'NOT'. For more complex expressions, use parentheses. Use the aliases from `component_conditions` to build expressions like `"A AND B"`, `"A OR B"`, `"(A AND B) OR C"`, or `"A AND (B OR C) AND NOT (D AND E)"`.
        """
        return pulumi.get(self, "trigger_expression")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AwsEuSovereignIntegrationsArgs', 'AwsEuSovereignIntegrations']

@pulumi.input_type
class AwsEuSovereignIntegrationsArgs:
    def __init__(__self__, *,
                 linked_account_id: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 billing: Optional[pulumi.Input['AwsEuSovereignIntegrationsBillingArgs']] = None,
                 cloudtrail: Optional[pulumi.Input['AwsEuSovereignIntegrationsCloudtrailArgs']] = None,
                 x_ray: Optional[pulumi.Input['AwsEuSovereignIntegrationsXRayArgs']] = None):
        """
        The set of arguments for constructing a AwsEuSovereignIntegrations resource.

        :param pulumi.Input[_builtins.str] linked_account_id: The ID of the linked AWS EU Sovereign account in New Relic.
        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID to operate on. This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input['AwsEuSovereignIntegrationsBillingArgs'] billing: Billing integration
        :param pulumi.Input['AwsEuSovereignIntegrationsCloudtrailArgs'] cloudtrail: CloudTrail integration
        :param pulumi.Input['AwsEuSovereignIntegrationsXRayArgs'] x_ray: X-Ray integration
        """
        pulumi.set(__self__, "linked_account_id", linked_account_id)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if billing is not None:
            pulumi.set(__self__, "billing", billing)
        if cloudtrail is not None:
            pulumi.set(__self__, "cloudtrail", cloudtrail)
        if x_ray is not None:
            pulumi.set(__self__, "x_ray", x_ray)

    @_builtins.property
    @pulumi.getter(name="linkedAccountId")
    def linked_account_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the linked AWS EU Sovereign account in New Relic.
        """
        return pulumi.get(self, "linked_account_id")

    @linked_account_id.setter
    def linked_account_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "linked_account_id", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The New Relic account ID to operate on. This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def billing(self) -> Optional[pulumi.Input['AwsEuSovereignIntegrationsBillingArgs']]:
        """
        Billing integration
        """
        return pulumi.get(self, "billing")

    @billing.setter
    def billing(self, value: Optional[pulumi.Input['AwsEuSovereignIntegrationsBillingArgs']]):
        pulumi.set(self, "billing", value)

    @_builtins.property
    @pulumi.getter
    def cloudtrail(self) -> Optional[pulumi.Input['AwsEuSovereignIntegrationsCloudtrailArgs']]:
        """
        CloudTrail integration
        """
        return pulumi.get(self, "cloudtrail")

    @cloudtrail.setter
    def cloudtrail(self, value: Optional[pulumi.Input['AwsEuSovereignIntegrationsCloudtrailArgs']]):
        pulumi.set(self, "cloudtrail", value)

    @_builtins.property
    @pulumi.getter(name="xRay")
    def x_ray(self) -> Optional[pulumi.Input['AwsEuSovereignIntegrationsXRayArgs']]:
        """
        X-Ray integration
        """
        return pulumi.get(self, "x_ray")

    @x_ray.setter
    def x_ray(self, value: Optional[pulumi.Input['AwsEuSovereignIntegrationsXRayArgs']]):
        pulumi.set(self, "x_ray", value)


@pulumi.input_type
class _AwsEuSovereignIntegrationsState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 billing: Optional[pulumi.Input['AwsEuSovereignIntegrationsBillingArgs']] = None,
                 cloudtrail: Optional[pulumi.Input['AwsEuSovereignIntegrationsCloudtrailArgs']] = None,
                 linked_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 x_ray: Optional[pulumi.Input['AwsEuSovereignIntegrationsXRayArgs']] = None):
        """
        Input properties used for looking up and filtering AwsEuSovereignIntegrations resources.

        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID to operate on. This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input['AwsEuSovereignIntegrationsBillingArgs'] billing: Billing integration
        :param pulumi.Input['AwsEuSovereignIntegrationsCloudtrailArgs'] cloudtrail: CloudTrail integration
        :param pulumi.Input[_builtins.str] linked_account_id: The ID of the linked AWS EU Sovereign account in New Relic.
        :param pulumi.Input['AwsEuSovereignIntegrationsXRayArgs'] x_ray: X-Ray integration
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if billing is not None:
            pulumi.set(__self__, "billing", billing)
        if cloudtrail is not None:
            pulumi.set(__self__, "cloudtrail", cloudtrail)
        if linked_account_id is not None:
            pulumi.set(__self__, "linked_account_id", linked_account_id)
        if x_ray is not None:
            pulumi.set(__self__, "x_ray", x_ray)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The New Relic account ID to operate on. This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def billing(self) -> Optional[pulumi.Input['AwsEuSovereignIntegrationsBillingArgs']]:
        """
        Billing integration
        """
        return pulumi.get(self, "billing")

    @billing.setter
    def billing(self, value: Optional[pulumi.Input['AwsEuSovereignIntegrationsBillingArgs']]):
        pulumi.set(self, "billing", value)

    @_builtins.property
    @pulumi.getter
    def cloudtrail(self) -> Optional[pulumi.Input['AwsEuSovereignIntegrationsCloudtrailArgs']]:
        """
        CloudTrail integration
        """
        return pulumi.get(self, "cloudtrail")

    @cloudtrail.setter
    def cloudtrail(self, value: Optional[pulumi.Input['AwsEuSovereignIntegrationsCloudtrailArgs']]):
        pulumi.set(self, "cloudtrail", value)

    @_builtins.property
    @pulumi.getter(name="linkedAccountId")
    def linked_account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the linked AWS EU Sovereign account in New Relic.
        """
        return pulumi.get(self, "linked_account_id")

    @linked_account_id.setter
    def linked_account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_account_id", value)

    @_builtins.property
    @pulumi.getter(name="xRay")
    def x_ray(self) -> Optional[pulumi.Input['AwsEuSovereignIntegrationsXRayArgs']]:
        """
        X-Ray integration
        """
        return pulumi.get(self, "x_ray")

    @x_ray.setter
    def x_ray(self, value: Optional[pulumi.Input['AwsEuSovereignIntegrationsXRayArgs']]):
        pulumi.set(self, "x_ray", value)


@pulumi.type_token("newrelic:cloud/awsEuSovereignIntegrations:AwsEuSovereignIntegrations")
class AwsEuSovereignIntegrations(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 billing: Optional[pulumi.Input[Union['AwsEuSovereignIntegrationsBillingArgs', 'AwsEuSovereignIntegrationsBillingArgsDict']]] = None,
                 cloudtrail: Optional[pulumi.Input[Union['AwsEuSovereignIntegrationsCloudtrailArgs', 'AwsEuSovereignIntegrationsCloudtrailArgsDict']]] = None,
                 linked_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 x_ray: Optional[pulumi.Input[Union['AwsEuSovereignIntegrationsXRayArgs', 'AwsEuSovereignIntegrationsXRayArgsDict']]] = None,
                 __props__=None):
        """
        Use this resource to integrate AWS EU Sovereign services with New Relic.

        ## Prerequisite

        Setup is required for this resource to work properly. This resource assumes you have linked an AWS EU Sovereign account to New Relic.

        The New Relic AWS EU Sovereign integration relies on two mechanisms to get data into New Relic:

        * **CloudWatch Metric Streams (PUSH)**: This is the supported method for AWS EU Sovereign Cloud to get metrics into New Relic for the majority of AWS services. Follow the [steps outlined here](https://docs-preview.newrelic.com/docs/aws-eu-sovereign-cloud-integration) to set up a metric stream.

        * **API Polling (PULL)**: Required for services that are **not supported** by CloudWatch Metric Streams. The following three services must be integrated via API Polling: **Billing**, **CloudTrail** and **X-Ray**. Follow the [steps outlined here](https://docs-preview.newrelic.com/docs/aws-eu-sovereign-cloud-integration).

        This resource is used to configure API Polling integrations for those three services that are not available through AWS CloudWatch Metric Streams.

        ## Example Usage

        The following example demonstrates the use of the `cloud.AwsEuSovereignIntegrations` resource with multiple AWS EU Sovereign integrations supported by the resource.

        To view a full example with all supported AWS EU Sovereign integrations, please see the Additional Examples section. Integration blocks used in the resource may also be left empty to use the default configuration of the integration.

        A full example, inclusive of setup of AWS resources (from the AWS Terraform Provider) associated with this resource, may be found in our AWS EU Sovereign cloud integration guide.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.cloud.AwsEuSovereignLinkAccount("foo",
            arn="arn:aws-eusc:iam::123456789012:role/NewRelicInfrastructure-Integrations",
            metric_collection_mode="PULL",
            name="my-eu-sovereign-account")
        bar = newrelic.cloud.AwsEuSovereignIntegrations("bar",
            linked_account_id=foo.id,
            billing={
                "metrics_polling_interval": 3600,
            },
            cloudtrail={
                "metrics_polling_interval": 300,
                "aws_regions": ["eusc-de-east-1"],
            },
            x_ray={
                "metrics_polling_interval": 300,
                "aws_regions": ["eusc-de-east-1"],
            })
        ```

        ## Supported AWS EU Sovereign Integrations

        > **NOTE:** CloudWatch Metric Streams is the only supported method for AWS EU Sovereign Cloud. The following three integrations are for services **not supported by CloudWatch Metric Streams** and must be configured via API Polling using this resource.

        <details>
          <summary>Expand this section to view all supported AWS EU Sovereign services that may be integrated via this resource.</summary>

        | Block                  | Description                   |
        |------------------------|-------------------------------|
        | `billing`              | Billing Integration           |
        | `cloudtrail`           | CloudTrail Integration        |
        | `x_ray`                | X-Ray Integration             |

        </details>

        ## Additional Examples

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        bar = newrelic.cloud.AwsEuSovereignIntegrations("bar",
            linked_account_id=foo["id"],
            billing={
                "metrics_polling_interval": 300,
            },
            cloudtrail={
                "metrics_polling_interval": 900,
                "aws_regions": ["eusc-de-east-1"],
            },
            x_ray={
                "metrics_polling_interval": 300,
                "aws_regions": ["eusc-de-east-1"],
            })
        ```

        ## Import

        Linked AWS EU Sovereign account integrations can be imported using the `id`, e.g.

        ```sh
        $ pulumi import newrelic:cloud/awsEuSovereignIntegrations:AwsEuSovereignIntegrations foo <id>
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID to operate on. This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input[Union['AwsEuSovereignIntegrationsBillingArgs', 'AwsEuSovereignIntegrationsBillingArgsDict']] billing: Billing integration
        :param pulumi.Input[Union['AwsEuSovereignIntegrationsCloudtrailArgs', 'AwsEuSovereignIntegrationsCloudtrailArgsDict']] cloudtrail: CloudTrail integration
        :param pulumi.Input[_builtins.str] linked_account_id: The ID of the linked AWS EU Sovereign account in New Relic.
        :param pulumi.Input[Union['AwsEuSovereignIntegrationsXRayArgs', 'AwsEuSovereignIntegrationsXRayArgsDict']] x_ray: X-Ray integration
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AwsEuSovereignIntegrationsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to integrate AWS EU Sovereign services with New Relic.

        ## Prerequisite

        Setup is required for this resource to work properly. This resource assumes you have linked an AWS EU Sovereign account to New Relic.

        The New Relic AWS EU Sovereign integration relies on two mechanisms to get data into New Relic:

        * **CloudWatch Metric Streams (PUSH)**: This is the supported method for AWS EU Sovereign Cloud to get metrics into New Relic for the majority of AWS services. Follow the [steps outlined here](https://docs-preview.newrelic.com/docs/aws-eu-sovereign-cloud-integration) to set up a metric stream.

        * **API Polling (PULL)**: Required for services that are **not supported** by CloudWatch Metric Streams. The following three services must be integrated via API Polling: **Billing**, **CloudTrail** and **X-Ray**. Follow the [steps outlined here](https://docs-preview.newrelic.com/docs/aws-eu-sovereign-cloud-integration).

        This resource is used to configure API Polling integrations for those three services that are not available through AWS CloudWatch Metric Streams.

        ## Example Usage

        The following example demonstrates the use of the `cloud.AwsEuSovereignIntegrations` resource with multiple AWS EU Sovereign integrations supported by the resource.

        To view a full example with all supported AWS EU Sovereign integrations, please see the Additional Examples section. Integration blocks used in the resource may also be left empty to use the default configuration of the integration.

        A full example, inclusive of setup of AWS resources (from the AWS Terraform Provider) associated with this resource, may be found in our AWS EU Sovereign cloud integration guide.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.cloud.AwsEuSovereignLinkAccount("foo",
            arn="arn:aws-eusc:iam::123456789012:role/NewRelicInfrastructure-Integrations",
            metric_collection_mode="PULL",
            name="my-eu-sovereign-account")
        bar = newrelic.cloud.AwsEuSovereignIntegrations("bar",
            linked_account_id=foo.id,
            billing={
                "metrics_polling_interval": 3600,
            },
            cloudtrail={
                "metrics_polling_interval": 300,
                "aws_regions": ["eusc-de-east-1"],
            },
            x_ray={
                "metrics_polling_interval": 300,
                "aws_regions": ["eusc-de-east-1"],
            })
        ```

        ## Supported AWS EU Sovereign Integrations

        > **NOTE:** CloudWatch Metric Streams is the only supported method for AWS EU Sovereign Cloud. The following three integrations are for services **not supported by CloudWatch Metric Streams** and must be configured via API Polling using this resource.

        <details>
          <summary>Expand this section to view all supported AWS EU Sovereign services that may be integrated via this resource.</summary>

        | Block                  | Description                   |
        |------------------------|-------------------------------|
        | `billing`              | Billing Integration           |
        | `cloudtrail`           | CloudTrail Integration        |
        | `x_ray`                | X-Ray Integration             |

        </details>

        ## Additional Examples

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        bar = newrelic.cloud.AwsEuSovereignIntegrations("bar",
            linked_account_id=foo["id"],
            billing={
                "metrics_polling_interval": 300,
            },
            cloudtrail={
                "metrics_polling_interval": 900,
                "aws_regions": ["eusc-de-east-1"],
            },
            x_ray={
                "metrics_polling_interval": 300,
                "aws_regions": ["eusc-de-east-1"],
            })
        ```

        ## Import

        Linked AWS EU Sovereign account integrations can be imported using the `id`, e.g.

        ```sh
        $ pulumi import newrelic:cloud/awsEuSovereignIntegrations:AwsEuSovereignIntegrations foo <id>
        ```


        :param str resource_name: The name of the resource.
        :param AwsEuSovereignIntegrationsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AwsEuSovereignIntegrationsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 billing: Optional[pulumi.Input[Union['AwsEuSovereignIntegrationsBillingArgs', 'AwsEuSovereignIntegrationsBillingArgsDict']]] = None,
                 cloudtrail: Optional[pulumi.Input[Union['AwsEuSovereignIntegrationsCloudtrailArgs', 'AwsEuSovereignIntegrationsCloudtrailArgsDict']]] = None,
                 linked_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 x_ray: Optional[pulumi.Input[Union['AwsEuSovereignIntegrationsXRayArgs', 'AwsEuSovereignIntegrationsXRayArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AwsEuSovereignIntegrationsArgs.__new__(AwsEuSovereignIntegrationsArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["billing"] = billing
            __props__.__dict__["cloudtrail"] = cloudtrail
            if linked_account_id is None and not opts.urn:
                raise TypeError("Missing required property 'linked_account_id'")
            __props__.__dict__["linked_account_id"] = linked_account_id
            __props__.__dict__["x_ray"] = x_ray
        super(AwsEuSovereignIntegrations, __self__).__init__(
            'newrelic:cloud/awsEuSovereignIntegrations:AwsEuSovereignIntegrations',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            billing: Optional[pulumi.Input[Union['AwsEuSovereignIntegrationsBillingArgs', 'AwsEuSovereignIntegrationsBillingArgsDict']]] = None,
            cloudtrail: Optional[pulumi.Input[Union['AwsEuSovereignIntegrationsCloudtrailArgs', 'AwsEuSovereignIntegrationsCloudtrailArgsDict']]] = None,
            linked_account_id: Optional[pulumi.Input[_builtins.str]] = None,
            x_ray: Optional[pulumi.Input[Union['AwsEuSovereignIntegrationsXRayArgs', 'AwsEuSovereignIntegrationsXRayArgsDict']]] = None) -> 'AwsEuSovereignIntegrations':
        """
        Get an existing AwsEuSovereignIntegrations resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID to operate on. This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input[Union['AwsEuSovereignIntegrationsBillingArgs', 'AwsEuSovereignIntegrationsBillingArgsDict']] billing: Billing integration
        :param pulumi.Input[Union['AwsEuSovereignIntegrationsCloudtrailArgs', 'AwsEuSovereignIntegrationsCloudtrailArgsDict']] cloudtrail: CloudTrail integration
        :param pulumi.Input[_builtins.str] linked_account_id: The ID of the linked AWS EU Sovereign account in New Relic.
        :param pulumi.Input[Union['AwsEuSovereignIntegrationsXRayArgs', 'AwsEuSovereignIntegrationsXRayArgsDict']] x_ray: X-Ray integration
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AwsEuSovereignIntegrationsState.__new__(_AwsEuSovereignIntegrationsState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["billing"] = billing
        __props__.__dict__["cloudtrail"] = cloudtrail
        __props__.__dict__["linked_account_id"] = linked_account_id
        __props__.__dict__["x_ray"] = x_ray
        return AwsEuSovereignIntegrations(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The New Relic account ID to operate on. This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def billing(self) -> pulumi.Output[Optional['outputs.AwsEuSovereignIntegrationsBilling']]:
        """
        Billing integration
        """
        return pulumi.get(self, "billing")

    @_builtins.property
    @pulumi.getter
    def cloudtrail(self) -> pulumi.Output[Optional['outputs.AwsEuSovereignIntegrationsCloudtrail']]:
        """
        CloudTrail integration
        """
        return pulumi.get(self, "cloudtrail")

    @_builtins.property
    @pulumi.getter(name="linkedAccountId")
    def linked_account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the linked AWS EU Sovereign account in New Relic.
        """
        return pulumi.get(self, "linked_account_id")

    @_builtins.property
    @pulumi.getter(name="xRay")
    def x_ray(self) -> pulumi.Output[Optional['outputs.AwsEuSovereignIntegrationsXRay']]:
        """
        X-Ray integration
        """
        return pulumi.get(self, "x_ray")

